# -*- coding: utf-8 -*-
""" [Settings]
    Project Settings { app.settings }.
"""
import pathlib

# Base Directory
BASE_DIR = pathlib.Path(__file__).parents[1]

# Installed Apps
INSTALLED_APPS = ["demo"]
